from urllib.parse import urlparse

from .base_test_case import BaseTestCase, Producer


class ProducerTestCase(BaseTestCase):
    def test_queue_creation(self):
        queue_name = self.fake.pystr(max_chars=10)
        producer = self.get_producer(queue_name)
        self.assertEqual(producer.queue_name, queue_name)
        url = urlparse(producer.queue.url)
        self.assertEqual(url.path, f"/100010001000/{queue_name}")

    def test_invalid_producer(self):
        self.assertRaises(ValueError, Producer)

    def test_message_publish(self):
        queue_name = self.fake.pystr(max_chars=10)
        producer = self.get_producer(queue_name)
        data = self.fake.json(
            data_columns={
                "name": "company",
                "phrase": "catch_phrase",
                "description": "bs",
                "address": "address",
            }
        )
        return_data = producer.publish(data)
        response_metadata = return_data.get("ResponseMetadata")
        self.assertEqual(response_metadata.get("HTTPStatusCode"), 200)



from unittest import TestCase

from botocore.exceptions import (
    NoCredentialsError,
    NoRegionError,
    EndpointConnectionError,
)

from sqspy import Consumer
from sqspy._base import Base
from .config import TestConfig


class ConnectionTestCase(TestCase):
    def test_endpoint_connection(self):
        base = Base(
            endpoint_url=TestConfig.endpoint_url, region_name=TestConfig.region_name
        )
        self.assertIsNotNone(base)

    def test_connection_error(self):
        self.assertRaises(
            (NoCredentialsError, NoRegionError, EndpointConnectionError),
            Consumer,
            "queue_name",
            region_name=None,
            endpoint_url="http://localhost/",
        )



import logging
from typing import Dict

import boto3
import boto3.session

sqspy_logger = logging.getLogger("sqspy")


class Base:
    QUEUE_VISIBILITY_TIMEOUT = "600"

    def __init__(self, **kwargs):
        aws_access_key_id = kwargs.get("aws_access_key_id")
        aws_secret_access_key = kwargs.get("aws_secret_access_key")
        profile_name = kwargs.get("profile_name")
        endpoint_url = kwargs.get("endpoint_url")
        region_name = kwargs.get("region_name")
        self._session = boto3.session.Session(
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
            profile_name=profile_name,
            region_name=region_name,
        )
        self._sqs = self._session.resource(
            "sqs",
            region_name=region_name,
            endpoint_url=endpoint_url,
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
        )
        sqspy_logger.debug("Initialised SQS resource")

    def get_or_create_queue(self, queue_data: Dict, create_queue: bool = True):
        queue_name = queue_data.get("name")
        queue_visibility: str = (
                queue_data.get("visibility_timeout") or self.QUEUE_VISIBILITY_TIMEOUT
        )
        queue = self.get_queue(queue_data)
        if queue is not None:
            return queue
        if create_queue is False:
            sqspy_logger.warning("Denied creation of queue.")
            return None
        sqspy_logger.debug(f"Creating the queue: {queue_name}")
        queue_attributes = {
            "VisibilityTimeout": queue_visibility,
        }
        if queue_name.endswith(".fifo"):
            queue_attributes["FifoQueue"] = "true"
        return self.create_queue(queue_name, queue_attributes)

    def get_queue(self, queue_data: Dict):
        queue_url = queue_data.get("url")
        queue_name = queue_data.get("name")
        if queue_url:
            return self._sqs.Queue(queue_url)
        for q in self._sqs.queues.filter(QueueNamePrefix=queue_name):
            name = q.url.split("/")[-1]
            if name == queue_name:
                return q
        sqspy_logger.warning("Queue not found.")
        return None

    def create_queue(self, name: str, attributes: Dict):
        return self._sqs.create_queue(QueueName=name, Attributes=attributes)



MAJOR = 0
MINOR = 1
PATCH = 0
SUFFIX = ""

NAME = "sqspy"

AUTHOR = MAINTAINER = {
    "name": "hjpotter92",
    "email": "hjpotter92+pypi@gmail.com",
}

AUTHORS = MAINTAINERS = (f"{AUTHOR.get('name')} <{AUTHOR.get('email')}>",)

__version__ = VERSION = f"{MAJOR}.{MINOR}.{PATCH}{SUFFIX}"



from json import loads

from .base_test_case import BaseTestCase


class ProducerTestCase(BaseTestCase):
    def test_message_acknowledgement(self):
        queue_name = self.fake.pystr(max_chars=10)
        producer = self.get_producer(queue_name)
        consumer = self.get_consumer(queue_name, max_number_of_messages=1)
        message = self.fake.json(
            data_columns={
                "name": "company",
                "phrase": "catch_phrase",
                "description": "bs",
                "address": "address",
            }
        )
        message_data = producer.publish(message)
        fetched_message = consumer.poll_messages()[0]
        self.assertEqual(
            fetched_message.md5_of_body, message_data.get("MD5OfMessageBody")
        )
        self.assertEqual(fetched_message.message_id, message_data.get("MessageId"))
        self.assertEqual(message, loads(fetched_message.body))



from unittest import TestCase
from faker import Faker
from sqspy import Consumer, Producer
from .config import TestConfig


class ConsumerTest(Consumer):
    def handle_message(self, body, attributes, messages_attributes):
        return body, attributes, messages_attributes


class BaseTestCase(TestCase):
    def setUp(self) -> None:
        self.fake = Faker()

    @staticmethod
    def get_producer(queue_name, *args, **kwargs):
        return Producer(
            queue_name,
            aws_access_key_id=TestConfig.aws_access_key_id,
            aws_secret_access_key=TestConfig.aws_secret_access_key,
            endpoint_url=TestConfig.endpoint_url,
            region_name=TestConfig.region_name,
            *args,
            **kwargs,
        )

    @staticmethod
    def get_consumer(queue_name, *args, **kwargs):
        return ConsumerTest(
            queue_name,
            aws_access_key_id=TestConfig.aws_access_key_id,
            aws_secret_access_key=TestConfig.aws_secret_access_key,
            endpoint_url=TestConfig.endpoint_url,
            region_name=TestConfig.region_name,
            *args,
            **kwargs,
        )



from urllib.parse import urlparse

from .base_test_case import BaseTestCase, ConsumerTest


class ConsumerTestCase(BaseTestCase):
    def test_queue_creation(self):
        queue_name = self.fake.pystr(max_chars=10)
        consumer = self.get_consumer(queue_name)
        self.assertEqual(consumer.queue_name, queue_name)
        url = urlparse(consumer.queue.url)
        self.assertEqual(url.path, f"/100010001000/{queue_name}")

    def test_invalid_consumer(self):
        self.assertRaises(ValueError, ConsumerTest)



from os import getenv


class TestConfig:
    aws_access_key_id: str = "XXXXXXXXXXXXXXXX"
    aws_secret_access_key: str = "XXXXXXXXXXXXXXXXXXXXXXXXXX"
    endpoint_url: str = getenv("ENDPOINT_URL")
    region_name: str = getenv("AWS_DEFAULT_REGION") or getenv("REGION_NAME")
